<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package OTAKU
 * @since OTAKU 1.0
 */

$otaku_template = apply_filters( 'otaku_filter_get_template_part', otaku_blog_archive_get_template() );

if ( ! empty( $otaku_template ) && 'index' != $otaku_template ) {

	get_template_part( $otaku_template );

} else {

	otaku_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$otaku_stickies   = is_home()
								|| ( in_array( otaku_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) otaku_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$otaku_post_type  = otaku_get_theme_option( 'post_type' );
		$otaku_args       = array(
								'blog_style'     => otaku_get_theme_option( 'blog_style' ),
								'post_type'      => $otaku_post_type,
								'taxonomy'       => otaku_get_post_type_taxonomy( $otaku_post_type ),
								'parent_cat'     => otaku_get_theme_option( 'parent_cat' ),
								'posts_per_page' => otaku_get_theme_option( 'posts_per_page' ),
								'sticky'         => otaku_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $otaku_stickies )
															&& count( $otaku_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		otaku_blog_archive_start();

		do_action( 'otaku_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'otaku_action_before_page_author' );
			get_template_part( apply_filters( 'otaku_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'otaku_action_after_page_author' );
		}

		if ( otaku_get_theme_option( 'show_filters' ) ) {
			do_action( 'otaku_action_before_page_filters' );
			otaku_show_filters( $otaku_args );
			do_action( 'otaku_action_after_page_filters' );
		} else {
			do_action( 'otaku_action_before_page_posts' );
			otaku_show_posts( array_merge( $otaku_args, array( 'cat' => $otaku_args['parent_cat'] ) ) );
			do_action( 'otaku_action_after_page_posts' );
		}

		do_action( 'otaku_action_blog_archive_end' );

		otaku_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'otaku_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'otaku_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
