<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package OTAKU
 * @since OTAKU 1.0
 */

if ( otaku_sidebar_present() ) {
	
	$otaku_sidebar_type = otaku_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $otaku_sidebar_type && ! otaku_is_layouts_available() ) {
		$otaku_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $otaku_sidebar_type ) {
		// Default sidebar with widgets
		$otaku_sidebar_name = otaku_get_theme_option( 'sidebar_widgets' );
		otaku_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $otaku_sidebar_name ) ) {
			dynamic_sidebar( $otaku_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$otaku_sidebar_id = otaku_get_custom_sidebar_id();
		do_action( 'otaku_action_show_layout', $otaku_sidebar_id );
	}
	$otaku_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $otaku_out ) ) {
		$otaku_sidebar_position    = otaku_get_theme_option( 'sidebar_position' );
		$otaku_sidebar_position_ss = otaku_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $otaku_sidebar_position );
			echo ' sidebar_' . esc_attr( $otaku_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $otaku_sidebar_type );

			$otaku_sidebar_scheme = apply_filters( 'otaku_filter_sidebar_scheme', otaku_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $otaku_sidebar_scheme ) && ! otaku_is_inherit( $otaku_sidebar_scheme ) && 'custom' != $otaku_sidebar_type ) {
				echo ' scheme_' . esc_attr( $otaku_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="otaku_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'otaku_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $otaku_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$otaku_title = apply_filters( 'otaku_filter_sidebar_control_title', 'float' == $otaku_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'otaku' ) : '' );
				$otaku_text  = apply_filters( 'otaku_filter_sidebar_control_text', 'above' == $otaku_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'otaku' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $otaku_title ); ?>"><?php echo esc_html( $otaku_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'otaku_action_before_sidebar', 'sidebar' );
				otaku_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $otaku_out ) );
				do_action( 'otaku_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'otaku_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
